Translates a reticular action model (RAM) fitted or specified with
OpenMx into a UMG. Manifest variables become observed
vertices and latent variables become latent vertices; nonzero
entries of the asymmetric matrix A become directed dep edges
(with fixed values shown for non-free paths), and off-diagonal
entries of the symmetric matrix S become cov edges. This exposes
the path-diagram content of a RAM specification in the UMG lexicon.