Promotes a set of parameter or latent vertices to class-varying
quantities by adding a latent class vertex with mixing edges into
them, implementing the mixture move described in the accompanying
article. The latent growth model of umg_growth() wrapped this way
becomes a growth mixture model.
Examples
g <- umg_growth(4)
umg_mixture(g, targets = c("I", "S"))
#> Unified Model Graph (statistical badge)
#> vertices: 8 | edges: 12 | plates: 1
#> edge kinds: cov=1, dep=9, mix=2